<?php
/**
 * Swimming Pool Cleaning Theme Customizer
 * @package Swimming Pool Cleaning
 */

load_template( trailingslashit( get_template_directory() ) . '/inc/logo-sizer.php' );
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function swimming_pool_cleaning_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/custom-control.php' );
	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-changer.php' );

	$wp_customize->add_setting( 'swimming_pool_cleaning_logo_sizer',array(
		'default' => 50,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_logo_sizer',array(
		'label' => esc_html__( 'Logo Sizer','swimming-pool-cleaning' ),
		'section' => 'title_tagline',
		'priority'    => 9,
		'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));
 	// logo padding
	$wp_customize->add_setting( 'swimming_pool_cleaning_logo_padding',array(
		'default' => '',
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_logo_padding',array(
		'label' => esc_html__( 'Logo Padding','swimming-pool-cleaning' ),
		'section' => 'title_tagline',
		'priority'    => 9,
		'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));

	// logo margin
	$wp_customize->add_setting( 'swimming_pool_cleaning_logo_margin',array(
		'default' => '',
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_logo_margin',array(
		'label' => esc_html__( 'Logo Margin','swimming-pool-cleaning' ),
		'section' => 'title_tagline',
		'priority'    => 9,
		'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_site_title_enable',array(
		'default' => true,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_site_title_enable',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable Site Title','swimming-pool-cleaning'),
		'section' => 'title_tagline'
	));

 	$wp_customize->add_setting('swimming_pool_cleaning_site_title_font_size',array(
		'default'=> 25,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_site_title_font_size',array(
		'label' => esc_html__( 'Site Title Font Size (px)','swimming-pool-cleaning' ),
		'section'=> 'title_tagline',
		'input_attrs' => array(
         'step' => 1,
			'min'  => 0,
			'max'  => 50,
      ),
	)));

	// site title color
   $wp_customize->add_setting('swimming_pool_cleaning_site_title_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_site_title_color', array(
		'label'    => __('Site Title Color', 'swimming-pool-cleaning'),
		'section'  => 'title_tagline',
		'settings' => 'swimming_pool_cleaning_site_title_color',
	)));

   $wp_customize->add_setting('swimming_pool_cleaning_site_tagline_enable',array(
      'default' => true,
      'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_site_tagline_enable',array(
      'type' => 'checkbox',
      'label' => __('Enable / Disable Site Tagline','swimming-pool-cleaning'),
      'section' => 'title_tagline'
   ));

   $wp_customize->add_setting('swimming_pool_cleaning_site_tagline_font_size',array(
		'default'=> 13,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_site_tagline_font_size',array(
		'label' => esc_html__( 'Site Tagline Font Size (px)','swimming-pool-cleaning' ),
		'section'=> 'title_tagline',
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
	)));

	// site tagline color
	$wp_customize->add_setting('swimming_pool_cleaning_site_tagline_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_site_tagline_color', array(
		'label'    => __('Site Tagline Color', 'swimming-pool-cleaning'),
		'section'  => 'title_tagline',
		'settings' => 'swimming_pool_cleaning_site_tagline_color',
	)));

    $wp_customize->add_setting('swimming_pool_cleaning_site_logo_inline',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_site_logo_inline',array(
       'type' => 'checkbox',
       'label' => __('Site logo inline with site title','swimming-pool-cleaning'),
       'section' => 'title_tagline',
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_background_skin',array(
        'default' => 'Without Background',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_background_skin',array(
        'type' => 'radio',
        'label' => __('Background Skin','swimming-pool-cleaning'),
        'description' => __('Here you can add the background skin along with the background image.','swimming-pool-cleaning'),
        'section' => 'background_image',
        'choices' => array(
            'With Background' => __('With Background Skin','swimming-pool-cleaning'),
            'Without Background' => __('Without Background Skin','swimming-pool-cleaning'),
        ),
	) );

	//add home page setting pannel
	$wp_customize->add_panel( 'swimming_pool_cleaning_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'swimming-pool-cleaning' ),
	    'description' => __( 'Description of what this panel does.', 'swimming-pool-cleaning' ),
	) );

	$swimming_pool_cleaning_font_array = array(
		''                       => 'No Fonts',
		'Abril Fatface'          => 'Abril Fatface',
		'Acme'                   => 'Acme',
		'Anton'                  => 'Anton',
		'Architects Daughter'    => 'Architects Daughter',
		'Arimo'                  => 'Arimo',
		'Arsenal'                => 'Arsenal',
		'Arvo'                   => 'Arvo',
		'Alegreya'               => 'Alegreya',
		'Alfa Slab One'          => 'Alfa Slab One',
		'Averia Serif Libre'     => 'Averia Serif Libre',
		'Bangers'                => 'Bangers',
		'Boogaloo'               => 'Boogaloo',
		'Bad Script'             => 'Bad Script',
		'Bitter'                 => 'Bitter',
		'Bree Serif'             => 'Bree Serif',
		'BenchNine'              => 'BenchNine',
		'Cabin'                  => 'Cabin',
		'Cardo'                  => 'Cardo',
		'Courgette'              => 'Courgette',
		'Cherry Swash'           => 'Cherry Swash',
		'Cormorant Garamond'     => 'Cormorant Garamond',
		'Crimson Text'           => 'Crimson Text',
		'Cuprum'                 => 'Cuprum',
		'Cookie'                 => 'Cookie',
		'Chewy'                  => 'Chewy',
		'Days One'               => 'Days One',
		'Dosis'                  => 'Dosis',
		'Droid Sans'             => 'Droid Sans',
		'Economica'              => 'Economica',
		'Fredoka One'            => 'Fredoka One',
		'Fjalla One'             => 'Fjalla One',
		'Francois One'           => 'Francois One',
		'Frank Ruhl Libre'       => 'Frank Ruhl Libre',
		'Gloria Hallelujah'      => 'Gloria Hallelujah',
		'Great Vibes'            => 'Great Vibes',
		'Handlee'                => 'Handlee',
		'Hammersmith One'        => 'Hammersmith One',
		'Inconsolata'            => 'Inconsolata',
		'Indie Flower'           => 'Indie Flower',
		'IM Fell English SC'     => 'IM Fell English SC',
		'Julius Sans One'        => 'Julius Sans One',
		'Josefin Slab'           => 'Josefin Slab',
		'Josefin Sans'           => 'Josefin Sans',
		'Kanit'                  => 'Kanit',
		'Lobster'                => 'Lobster',
		'Lato'                   => 'Lato',
		'Lora'                   => 'Lora',
		'Libre Baskerville'      => 'Libre Baskerville',
		'Lobster Two'            => 'Lobster Two',
		'Merriweather'           => 'Merriweather',
		'Monda'                  => 'Monda',
		'Montserrat'             => 'Montserrat',
		'Muli'                   => 'Muli',
		'Marck Script'           => 'Marck Script',
		'Noto Serif'             => 'Noto Serif',
		'Open Sans'              => 'Open Sans',
		'Overpass'               => 'Overpass',
		'Overpass Mono'          => 'Overpass Mono',
		'Oxygen'                 => 'Oxygen',
		'Orbitron'               => 'Orbitron',
		'Patua One'              => 'Patua One',
		'Pacifico'               => 'Pacifico',
		'Padauk'                 => 'Padauk',
		'Playball'               => 'Playball',
		'Playfair Display'       => 'Playfair Display',
		'PT Sans'                => 'PT Sans',
		'Philosopher'            => 'Philosopher',
		'Permanent Marker'       => 'Permanent Marker',
		'Poiret One'             => 'Poiret One',
		'Quicksand'              => 'Quicksand',
		'Quattrocento Sans'      => 'Quattrocento Sans',
		'Raleway'                => 'Raleway',
		'Rubik'                  => 'Rubik',
		'Rokkitt'                => 'Rokkitt',
		'Russo One'              => 'Russo One',
		'Righteous'              => 'Righteous',
		'Slabo'                  => 'Slabo',
		'Source Sans Pro'        => 'Source Sans Pro',
		'Shadows Into Light Two' => 'Shadows Into Light Two',
		'Shadows Into Light'     => 'Shadows Into Light',
		'Sacramento'             => 'Sacramento',
		'Shrikhand'              => 'Shrikhand',
		'Tangerine'              => 'Tangerine',
		'Ubuntu'                 => 'Ubuntu',
		'VT323'                  => 'VT323',
		'Varela Round'           => 'Varela Round',
		'Vampiro One'            => 'Vampiro One',
		'Vollkorn'               => 'Vollkorn',
		'Volkhov'                => 'Volkhov',
		'Yanone Kaffeesatz'      => 'Yanone Kaffeesatz'
	);

	//Typography
	$wp_customize->add_section('swimming_pool_cleaning_typography', array(
		'title'    => __('Typography', 'swimming-pool-cleaning'),
		'panel'    => 'swimming_pool_cleaning_panel_id',
	));

	//This is body FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_body_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_body_color', array(
		'label'    => __('Body Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_body_color',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_body_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(	'swimming_pool_cleaning_body_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('Body Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	$wp_customize->add_setting('swimming_pool_cleaning_body_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_body_font_size', array(
		'label'   => __('Body Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_body_font_size',
		'type'    => 'text',
	));

	// This is Paragraph Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_paragraph_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_paragraph_color', array(
		'label'    => __('Paragraph Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_paragraph_color',
	)));

	//This is Paragraph FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_paragraph_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(	'swimming_pool_cleaning_paragraph_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('Paragraph Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	$wp_customize->add_setting('swimming_pool_cleaning_paragraph_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_paragraph_font_size', array(
		'label'   => __('Paragraph Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_paragraph_font_size',
		'type'    => 'text',
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_atag_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_atag_color', array(
		'label'    => __('"a" Tag Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_atag_color',
	)));

	//This is "a" Tag FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_atag_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(	'swimming_pool_cleaning_atag_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('"a" Tag Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_li_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_li_color', array(
		'label'    => __('"li" Tag Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_li_color',
	)));

	//This is "li" Tag FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_li_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(	'swimming_pool_cleaning_li_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('"li" Tag Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	// This is H1 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h1_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h1_color', array(
		'label'    => __('H1 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h1_color',
	)));

	//This is H1 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h1_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h1_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('H1 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H1 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h1_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h1_font_size', array(
		'label'   => __('H1 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h1_font_size',
		'type'    => 'text',
	));

	// This is H2 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h2_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h2_color', array(
		'label'    => __('h2 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h2_color',
	)));

	//This is H2 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h2_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(
	'swimming_pool_cleaning_h2_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('h2 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H2 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h2_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h2_font_size', array(
		'label'   => __('H2 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h2_font_size',
		'type'    => 'text',
	));

	// This is H3 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h3_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h3_color', array(
		'label'    => __('H3 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h3_color',
	)));

	//This is H3 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h3_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control(
	'swimming_pool_cleaning_h3_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('H3 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H3 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h3_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h3_font_size', array(
		'label'   => __('H3 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h3_font_size',
		'type'    => 'text',
	));

	// This is H4 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h4_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h4_color', array(
		'label'    => __('H4 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h4_color',
	)));

	//This is H4 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h4_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h4_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('H4 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H4 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h4_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h4_font_size', array(
		'label'   => __('H4 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h4_font_size',
		'type'    => 'text',
	));

	// This is H5 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h5_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h5_color', array(
		'label'    => __('H5 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h5_color',
	)));

	//This is H5 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h5_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h5_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('H5 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H5 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h5_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h5_font_size', array(
		'label'   => __('H5 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h5_font_size',
		'type'    => 'text',
	));

	// This is H6 Color picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h6_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_h6_color', array(
		'label'    => __('H6 Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_typography',
		'settings' => 'swimming_pool_cleaning_h6_color',
	)));

	//This is H6 FontFamily picker setting
	$wp_customize->add_setting('swimming_pool_cleaning_h6_font_family', array(
		'default'           => '',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h6_font_family', array(
		'section' => 'swimming_pool_cleaning_typography',
		'label'   => __('H6 Fonts', 'swimming-pool-cleaning'),
		'type'    => 'select',
		'choices' => $swimming_pool_cleaning_font_array,
	));

	//This is H6 FontSize setting
	$wp_customize->add_setting('swimming_pool_cleaning_h6_font_size', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('swimming_pool_cleaning_h6_font_size', array(
		'label'   => __('H6 Font Size', 'swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_typography',
		'setting' => 'swimming_pool_cleaning_h6_font_size',
		'type'    => 'text',
	));

	//layout setting
	$wp_customize->add_section( 'swimming_pool_cleaning_option', array(
    	'title'      => __( 'Layout Settings', 'swimming-pool-cleaning' ),
    	'panel'    => 'swimming_pool_cleaning_panel_id',
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_single_page_breadcrumb',array(
			'default' => true,
	      	'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	    ) );
	$wp_customize->add_control('swimming_pool_cleaning_single_page_breadcrumb',array(
	    	'type' => 'checkbox',
	       'label' => __( 'Show / Hide Single Page Breadcrumb','swimming-pool-cleaning' ),
	       'section' => 'swimming_pool_cleaning_option'
	 ));

	$wp_customize->add_setting('swimming_pool_cleaning_preloader',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_preloader',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Preloader','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_option'
    ));

   $wp_customize->add_setting('swimming_pool_cleaning_preloader_type',array(
     	'default' => 'First Preloader Type',
     	'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_preloader_type',array(
      'type' => 'radio',
      'label' => __('Preloader Types','swimming-pool-cleaning'),
      'section' => 'swimming_pool_cleaning_option',
      'choices' => array(
         'First Preloader Type' => __('First Preloader Type','swimming-pool-cleaning'),
         'Second Preloader Type' => __('Second Preloader Type','swimming-pool-cleaning'),
      ),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_preloader_bg_color_option', array(
		'default'           => '#FFBB3B',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_preloader_bg_color_option', array(
		'label'    => __('Preloader Background Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_option',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_preloader_icon_color_option', array(
		'default'           => '#fff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_preloader_icon_color_option', array(
		'label'    => __('Preloader Icon Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_option',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_width_layout_options',array(
		'default' => 'Default',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_width_layout_options',array(
		'type' => 'radio',
		'label' => __('Container Box','swimming-pool-cleaning'),
		'description' => __('Here you can change the Width layout. ','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_option',
		'choices' => array(
		   'Default' => __('Default','swimming-pool-cleaning'),
		   'Container Layout' => __('Container Layout','swimming-pool-cleaning'),
		   'Box Layout' => __('Box Layout','swimming-pool-cleaning'),
		),
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('swimming_pool_cleaning_layout_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	) );
	$wp_customize->add_control('swimming_pool_cleaning_layout_options', array(
        'type' => 'select',
        'label' => __('Select different post sidebar layout','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_option',
        'choices' => array(
            'One Column' => __('One Column','swimming-pool-cleaning'),
            'Grid Layout' => __('Grid Layout','swimming-pool-cleaning'),
            'Left Sidebar' => __('Left Sidebar','swimming-pool-cleaning'),
            'Right Sidebar' => __('Right Sidebar','swimming-pool-cleaning')
        ),
	)   );

	$wp_customize->add_setting('swimming_pool_cleaning_sidebar_size',array(
        'default' => 'Sidebar 1/3',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_sidebar_size',array(
        'type' => 'radio',
        'label' => __('Sidebar Size Option','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_option',
        'choices' => array(
            'Sidebar 1/3' => __('Sidebar 1/3','swimming-pool-cleaning'),
            'Sidebar 1/4' => __('Sidebar 1/4','swimming-pool-cleaning'),
        ),
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_image_border_radius', array(
		'default'=> 0,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize,  'swimming_pool_cleaning_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_option',
		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	)) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_image_box_shadow',array(
		'default' => 0,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize,  'swimming_pool_cleaning_image_box_shadow',array(
		'label' => esc_html__( 'Featured Image Shadow','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_option',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
		'type'		=> 'range'
	)));

	//Blog Post Settings
	$wp_customize->add_section('swimming_pool_cleaning_post_settings', array(
		'title'    => __('Post General Settings', 'swimming-pool-cleaning'),
		'panel'    => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_post_layouts',array(
     'default' => 'Layout 2',
     'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_post_layouts', array(
		'type' => 'select',
		'label' => __('Post Layouts','swimming-pool-cleaning'),
		'description' => __('Here you can change the 3 different layouts of post','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_post_settings',
		'choices' => array(
		   'Layout 1' => __('Layouts 1','swimming-pool-cleaning'),
		   'Layout 2' => __('Layouts 2','swimming-pool-cleaning'),
		   'Layout 3' => __('Layouts 3','swimming-pool-cleaning'),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_metafields_date',array(
		'default' => true,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_metafields_date',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable Date ','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_post_settings'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_post_date_icon',array(
		'default'	=> 'far fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_post_date_icon',array(
		'label'	=> __('Post Date Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_post_settings',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('swimming_pool_cleaning_metafields_author',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_metafields_author',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Author','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_post_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_post_author_icon',array(
		'label'	=> __('Post Author Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_post_settings',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('swimming_pool_cleaning_metafields_comment',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_metafields_comment',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Comments','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_post_comment_icon',array(
		'default'	=> 'fas fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_post_comment_icon',array(
		'label'	=> __('Post Comment Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_post_settings',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('swimming_pool_cleaning_metafields_time',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_metafields_time',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Time','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_post_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_post_time_icon',array(
		'label'	=> __('Post Time Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_post_settings',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_post_featured_image',array(
       'default' => 'Image',
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_choices'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_post_featured_image',array(
       'type' => 'select',
       'label'	=> __('Post Image Options','swimming-pool-cleaning'),
       'choices' => array(
            'Image' => __('Image','swimming-pool-cleaning'),
            'Color' => __('Color','swimming-pool-cleaning'),
            'None' => __('None','swimming-pool-cleaning'),
        ),
      	'section'	=> 'swimming_pool_cleaning_post_settings',
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_post_featured_color', array(
		'default'           => '#FFBB3B',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_post_featured_color', array(
		'label'    => __('Post Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_post_settings',
		'settings' => 'swimming_pool_cleaning_post_featured_color',
		'active_callback' => 'swimming_pool_cleaning_post_color_enabled'
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_custom_post_color_width',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_custom_post_color_width',	array(
		'label' => esc_html__( 'Color Post Custom Width','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 500,
			'step' => 1,
		),
		'active_callback' => 'swimming_pool_cleaning_show_post_color'
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_custom_post_color_height',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_custom_post_color_height',array(
		'label' => esc_html__( 'Color Post Custom Height','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 350,
			'step' => 1,
		),
		'active_callback' => 'swimming_pool_cleaning_show_post_color'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_post_featured_image_dimention',array(
       'default' => 'Default',
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_choices'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_post_featured_image_dimention',array(
       'type' => 'select',
       'label'	=> __('Post Featured Image Dimention','swimming-pool-cleaning'),
       'choices' => array(
            'Default' => __('Default','swimming-pool-cleaning'),
            'Custom' => __('Custom','swimming-pool-cleaning'),
        ),
      	'section'	=> 'swimming_pool_cleaning_post_settings',
      	'active_callback' => 'swimming_pool_cleaning_enable_post_featured_image'
    ));

    $wp_customize->add_setting( 'swimming_pool_cleaning_post_featured_image_custom_width',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_post_featured_image_custom_width',	array(
		'label' => esc_html__( 'Post Featured Image Custom Width','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 500,
			'step' => 1,
		),
		'active_callback' => 'swimming_pool_cleaning_enable_post_image_custom_dimention'
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_post_featured_image_custom_height',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_post_featured_image_custom_height',	array(
		'label' => esc_html__( 'Post Featured Image Custom Height','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 350,
			'step' => 1,
		),
		'active_callback' => 'swimming_pool_cleaning_enable_post_image_custom_dimention'
	)));

    //Post excerpt
	$wp_customize->add_setting( 'swimming_pool_cleaning_post_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'swimming_pool_cleaning_post_excerpt_number', array(
		'label'       => esc_html__( 'Blog Post Content Limit','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_post_settings',
		'type'        => 'number',
		'settings'    => 'swimming_pool_cleaning_post_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_content_settings',array(
        'default' =>'Excerpt',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_content_settings',array(
        'type' => 'radio',
        'label' => __('Content Settings','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_post_settings',
        'choices' => array(
            'Excerpt' => __('Excerpt','swimming-pool-cleaning'),
            'Content' => __('Content','swimming-pool-cleaning'),
        ),
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_post_discription_suffix', array(
		'default'   => __('[...]','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'swimming_pool_cleaning_post_discription_suffix', array(
		'label'       => esc_html__( 'Post Excerpt Suffix','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_post_settings',
		'type'        => 'text',
		'settings'    => 'swimming_pool_cleaning_post_discription_suffix',
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_blog_post_meta_seperator', array(
		'default'   => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'swimming_pool_cleaning_blog_post_meta_seperator', array(
		'label'       => esc_html__( 'Meta Box','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_post_settings',
		'description' => __('Here you can add the seperator for meta box. e.g. "|",  ",", "/", etc. ','swimming-pool-cleaning'),
		'type'        => 'text',
		'settings'    => 'swimming_pool_cleaning_blog_post_meta_seperator',
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_button_text',array(
		'default'=> __('View More','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_button_text',array(
		'label'	=> __('Add Button Text','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'swimming_pool_cleaning_post_button_padding_top',array(
		'default' => 10,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_post_button_padding_top',	array(
		'label' => esc_html__( 'Button Top Bottom Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_post_button_padding_right',array(
		'default' => 10,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_post_button_padding_right',	array(
		'label' => esc_html__( 'Button Right Left Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_post_button_border_radius',array(
		'default' => '',
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_post_button_border_radius',array(
		'label' => esc_html__( 'Button Border Radius (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_enable_post_pagination',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_enable_post_pagination',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Blog Page Pagination','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_post_settings'
    ));

    $wp_customize->add_setting( 'swimming_pool_cleaning_post_pagination_position', array(
        'default'			=>  'Bottom',
        'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_choices'
    ));
    $wp_customize->add_control( 'swimming_pool_cleaning_post_pagination_position', array(
        'section' => 'swimming_pool_cleaning_post_settings',
        'type' => 'select',
        'label' => __( 'Post Pagination Position', 'swimming-pool-cleaning' ),
        'choices'		=> array(
            'Top'  => __( 'Top', 'swimming-pool-cleaning' ),
            'Bottom' => __( 'Bottom', 'swimming-pool-cleaning' ),
            'Both Top & Bottom' => __( 'Both Top & Bottom', 'swimming-pool-cleaning' ),
    )));

	$wp_customize->add_setting( 'swimming_pool_cleaning_pagination_settings', array(
        'default'			=> 'Numeric Pagination',
        'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_choices'
    ));
    $wp_customize->add_control( 'swimming_pool_cleaning_pagination_settings', array(
        'section' => 'swimming_pool_cleaning_post_settings',
        'type' => 'radio',
        'label' => __( 'Post Pagination', 'swimming-pool-cleaning' ),
        'choices'		=> array(
            'Numeric Pagination'  => __( 'Numeric Pagination', 'swimming-pool-cleaning' ),
            'next-prev' => __( 'Next / Previous', 'swimming-pool-cleaning' ),
    )));

    $wp_customize->add_setting('swimming_pool_cleaning_post_block_option',array(
        'default' => 'By Block',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_post_block_option',array(
        'type' => 'select',
        'label' => __('Blog Post Shown','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_post_settings',
        'choices' => array(
            'By Block' => __('By Block','swimming-pool-cleaning'),
            'By Without Block' => __('By Without Block','swimming-pool-cleaning'),
        ),
	) );

    //Single Post Settings
	$wp_customize->add_section('swimming_pool_cleaning_single_post_settings', array(
		'title'    => __('Single Post Settings', 'swimming-pool-cleaning'),
		'panel'    => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_bradcrumb',array(
				'default' => false,
				'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
		));
	$wp_customize->add_control('swimming_pool_cleaning_single_post_bradcrumb',array(
				'type' => 'checkbox',
				'label' => __('Enable / Disable bradcrumb','swimming-pool-cleaning'),
				'section' => 'swimming_pool_cleaning_single_post_settings',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_date',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_single_post_date',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Date ','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_single_post_date_icon',array(
		'default'	=> 'far fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_single_post_date_icon',array(
		'label'	=> __('Single Post Date Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_single_post_settings',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_author',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_single_post_author',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Author','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

   $wp_customize->add_setting('swimming_pool_cleaning_single_post_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
      $wp_customize,'swimming_pool_cleaning_single_post_author_icon',array(
		'label'	=> __('Single Post Author Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_single_post_settings',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_comment',array(
		'default' => true,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_single_post_comment',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable Comments','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_single_post_settings'
	));

 	$wp_customize->add_setting('swimming_pool_cleaning_single_post_comment_icon',array(
		'default'	=> 'fas fa-comments',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer( $wp_customize, 'swimming_pool_cleaning_single_post_comment_icon', array(
		'label'	=> __('Single Post Comment Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_single_post_settings',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_tags',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_single_post_tags',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Tags','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_single_post_time',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_single_post_time',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Time','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings',
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_single_post_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_single_post_time_icon',array(
		'label'	=> __('Single Post Time Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_single_post_settings',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_post_comment_enable',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_post_comment_enable',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable post comment','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings',
    ));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_featured_image',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_single_post_featured_image',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Featured image','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings',
    ));

	$wp_customize->add_setting('swimming_pool_cleaning_show_hide_single_post_categories',array(
			'default' => true,
			'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	  ));
	 $wp_customize->add_control('swimming_pool_cleaning_show_hide_single_post_categories',array(
			'type' => 'checkbox',
			'label' => __('Single Post Categories','swimming-pool-cleaning'),
			'section' => 'swimming_pool_cleaning_single_post_settings'
	   ));

	$wp_customize->add_setting('swimming_pool_cleaning_single_post_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	) );
	$wp_customize->add_control('swimming_pool_cleaning_single_post_layout', array(
        'type' => 'select',
        'label' => __('Select different Single post sidebar layout','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_single_post_settings',
        'choices' => array(
            'One Column' => __('One Column','swimming-pool-cleaning'),
            'Left Sidebar' => __('Left Sidebar','swimming-pool-cleaning'),
            'Right Sidebar' => __('Right Sidebar','swimming-pool-cleaning')
        ),
	)   );

	$wp_customize->add_setting( 'swimming_pool_cleaning_single_post_meta_seperator', array(
		'default'   => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'swimming_pool_cleaning_single_post_meta_seperator', array(
		'label'       => esc_html__( 'Single Post Meta Box Seperator','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_single_post_settings',
		'description' => __('Here you can add the seperator for meta box. e.g. "|",  ",", "/", etc. ','swimming-pool-cleaning'),
		'type'        => 'text',
		'settings'    => 'swimming_pool_cleaning_single_post_meta_seperator',
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_comment_form_width',array(
		'default' => '',
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_comment_form_width',	array(
		'label' => esc_html__( 'Comment Form Width','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_single_post_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 100,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_title_comment_form',array(
       'default' => __('Leave a Reply','swimming-pool-cleaning'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_title_comment_form',array(
       'type' => 'text',
       'label' => __('Comment Form Heading Text','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_comment_form_button_content',array(
       'default' => __('Post Comment','swimming-pool-cleaning'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_comment_form_button_content',array(
       'type' => 'text',
       'label' => __('Comment Form Button Text','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

	$wp_customize->add_setting('swimming_pool_cleaning_enable_single_post_pagination',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_enable_single_post_pagination',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Single Post Pagination','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
    ));

   $wp_customize->add_setting('swimming_pool_cleaning_prev_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_prev_text',array(
       'type' => 'text',
       'label' => __('Previous Navigation Text','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
   ));

   $wp_customize->add_setting('swimming_pool_cleaning_next_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_next_text',array(
       'type' => 'text',
       'label' => __('Next Navigation Text','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_single_post_settings'
   ));

	//Related Post Settings
	$wp_customize->add_section('swimming_pool_cleaning_related_settings', array(
		'title'    => __('Related Post Settings', 'swimming-pool-cleaning'),
		'panel'    => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting( 'swimming_pool_cleaning_related_enable_disable',array(
		'default' => true,
      	'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ) );
    $wp_customize->add_control('swimming_pool_cleaning_related_enable_disable',array(
    	'type' => 'checkbox',
        'label' => __( 'Enable / Disable Related Post','swimming-pool-cleaning' ),
        'section' => 'swimming_pool_cleaning_related_settings'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_related_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_related_title',array(
		'label'	=> __('Add Section Title','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_related_settings',
		'type'		=> 'text'
	));

	$wp_customize->add_setting( 'swimming_pool_cleaning_related_posts_count_number', array(
		'default'              => 3,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'swimming_pool_cleaning_related_posts_count_number', array(
		'label'       => esc_html__( 'Related Post Count','swimming-pool-cleaning' ),
		'section'     => 'swimming_pool_cleaning_related_settings',
		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 10,
		),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_related_posts_taxanomies',array(
        'default' => 'categories',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_related_posts_taxanomies',array(
        'type' => 'radio',
        'label' => __('Post Taxonomies','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_related_settings',
        'choices' => array(
            'categories' => __('Categories','swimming-pool-cleaning'),
            'tags' => __('Tags','swimming-pool-cleaning'),
        ),
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_related_post_excerpt_number',array(
		'default' => 15,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_related_post_excerpt_number',	array(
		'label' => esc_html__( 'Content Limit','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_related_settings',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

 	//contact us Section
	$wp_customize->add_section('swimming_pool_cleaning_header_section',array(
		'title'	=> __('Header','swimming-pool-cleaning'),
		'description'	=> __('Add contact details here','swimming-pool-cleaning'),
		'priority'	=> null,
		'panel' => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_timing_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
 	));
 	$wp_customize->add_control('swimming_pool_cleaning_timing_text',array(
		'type' => 'text',
		'label' => __('Add Time','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_header_section',
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_location',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_location',array(
		'label'	=> __('Enter Location Text','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_location1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_location1',array(
		'label'	=> __('Enter Location','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_email_address',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_email_address',array(
		'label'	=> __('Enter Email Address Text','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_email_address1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('swimming_pool_cleaning_email_address1',array(
		'label'	=> __('Enter Email Address','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_call_number',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_call_number',array(
		'label'	=> __('Enter Phone Text','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_number1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_phone_number'
	));
	$wp_customize->add_control('swimming_pool_cleaning_number1',array(
		'label'	=> __('Enter Phone No','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_header_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_header_btn_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
 	));
 	$wp_customize->add_control('swimming_pool_cleaning_header_btn_text',array(
		'type' => 'text',
		'label' => __('Add Button Text','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_header_section',
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_header_btn_url',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
 	));
 	$wp_customize->add_control('swimming_pool_cleaning_header_btn_url',array(
		'type' => 'text',
		'label' => __('Add Button URL','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_header_section',
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_menu_font_size_option',array(
		'default'=> 12,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize,'swimming_pool_cleaning_menu_font_size_option',array(
		'label'	=> __('Menu Font Size ','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_header_section',
		'input_attrs' => array(
         'step' => 1,
			'min'  => 0,
			'max'  => 50,
     	),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_menu_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize,'swimming_pool_cleaning_menu_padding',array(
		'label'	=> __('Main Menu Padding','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_header_section',
		'input_attrs' => array(
         'step' => 1,
			'min'  => 0,
			'max'  => 50,
      ),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_text_tranform_menu',array(
		'default' => 'Uppercase',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
 	));
 	$wp_customize->add_control('swimming_pool_cleaning_text_tranform_menu',array(
		'type' => 'select',
		'label' => __('Menu Text Transform','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_header_section',
		'choices' => array(
		   'Uppercase' => __('Uppercase','swimming-pool-cleaning'),
		   'Lowercase' => __('Lowercase','swimming-pool-cleaning'),
		   'Capitalize' => __('Capitalize','swimming-pool-cleaning'),
		),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_font_weight_option_menu',array(
		'default' => '500',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
 	));
 	$wp_customize->add_control('swimming_pool_cleaning_font_weight_option_menu',array(
		'type' => 'select',
		'label' => __('Menu Font Weight','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_header_section',
		'choices' => array(
		   '100' => __('100','swimming-pool-cleaning'),
         '200' => __('200','swimming-pool-cleaning'),
         '300' => __('300','swimming-pool-cleaning'),
         '400' => __('400','swimming-pool-cleaning'),
         '500' => __('500','swimming-pool-cleaning'),
         '600' => __('600','swimming-pool-cleaning'),
         '700' => __('700','swimming-pool-cleaning'),
         '800' => __('800','swimming-pool-cleaning'),
         '900' => __('900','swimming-pool-cleaning'),
		),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_menu_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_menu_color', array(
		'label'    => __('Menu Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_header_section',
		'settings' => 'swimming_pool_cleaning_menu_color',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_sub_menu_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_sub_menu_color', array(
		'label'    => __('Submenu Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_header_section',
		'settings' => 'swimming_pool_cleaning_sub_menu_color',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_menu_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_menu_hover_color', array(
		'label'    => __('Menu Hover Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_header_section',
		'settings' => 'swimming_pool_cleaning_menu_hover_color',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_sub_menu_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_sub_menu_hover_color', array(
		'label'    => __('Submenu Hover Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_header_section',
		'settings' => 'swimming_pool_cleaning_sub_menu_hover_color',
	)));

	//Slider Section
	$wp_customize->add_section( 'swimming_pool_cleaning_slider_section' , array(
    	'title'      => __( 'Slider Section', 'swimming-pool-cleaning' ),
		'priority'   => null,
		'panel' => 'swimming_pool_cleaning_panel_id'
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_slider_hide',array(
		'default' => false,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_slider_hide',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable slider','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_slider_section',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_slider_bg_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'swimming_pool_cleaning_slider_bg_image',array(
		'label' => __('Slider Background Image','swimming-pool-cleaning'),
		'description' => __('Image Size (1400px x 550px)','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_slider_section'
	)));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'swimming_pool_cleaning_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'swimming_pool_cleaning_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'swimming_pool_cleaning_slider' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'swimming-pool-cleaning' ),
			'section'  => 'swimming_pool_cleaning_slider_section',
			'type'     => 'dropdown-pages'
		) );
	}

	//Our Services
  	$wp_customize->add_section('swimming_pool_cleaning_our_services_section',array(
		'title' => __('Service Section','swimming-pool-cleaning'),
		'description' => '',
		'priority'  => null,
		'panel' => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_choose_us_enable',array(
		'default' => false,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_choose_us_enable',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable Service Section','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_our_services_section'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_section_small_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_section_small_title',array(
		'type' => 'text',
		'label' => __('Section Small Title','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_our_services_section'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_section_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_section_title',array(
		'type' => 'text',
		'label' => __('Section Title','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_our_services_section'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_service_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'swimming_pool_cleaning_service_image',array(
		'label' => __('Service Image','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_our_services_section'
	)));

	$categories = get_categories( );
 	$cats = array();
 	$i = 0;
 	foreach($categories as $category){
     	if($i==0){
         $default = $category->slug;
         $i++;
     	}
     $cats[$category->slug] = $category->name;
 	}

 	$wp_customize->add_setting('swimming_pool_cleaning_serv_category',array(
     	'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
 	));
	$wp_customize->add_control('swimming_pool_cleaning_serv_category',array(
		'type'    => 'select',
		'choices' => $cats,
		'label' => __('Select Service Category','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_our_services_section',
 	));

	$wp_customize->add_setting('swimming_pool_cleaning_choose_us_posts_number',array(
		'default'	=> 4,
     	'sanitize_callback' => 'sanitize_text_field',
 	));
	$wp_customize->add_control('swimming_pool_cleaning_choose_us_posts_number',array(
		'label' => __('Services Post to Show','swimming-pool-cleaning'),
		'type'    => 'number',
		'section' => 'swimming_pool_cleaning_our_services_section',
 	));

	$swimming_pool_cleaning_choose_us_posts_number = get_theme_mod('swimming_pool_cleaning_choose_us_posts_number', 4);
	for($i=1; $i <= $swimming_pool_cleaning_choose_us_posts_number; $i++){
		$wp_customize->add_setting('swimming_pool_cleaning_service_posts_icon' . $i, array(
		'default'	=> 'fas fa-wrench',
     	'sanitize_callback' => 'sanitize_text_field',
	 	));
		$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer($wp_customize,'swimming_pool_cleaning_service_posts_icon'. $i, array(
			'section' => 'swimming_pool_cleaning_our_services_section',
			'type'    => 'icon',
			'label' => esc_html__('Service Icon ','swimming-pool-cleaning') . $i
	 	)));
	}

	//footer text
	$wp_customize->add_section('swimming_pool_cleaning_footer_section',array(
		'title'	=> __('Footer Text','swimming-pool-cleaning'),
		'panel' => 'swimming_pool_cleaning_panel_id'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_footer_bg_color', array(
		'default'           => '#0d0d0f',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_footer_bg_color', array(
		'label'    => __('Footer Background Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_footer_section',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_footer_bg_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'swimming_pool_cleaning_footer_bg_image',array(
		'label' => __('Footer Background Image','swimming-pool-cleaning'),
		'section' => 'swimming_pool_cleaning_footer_section'
	)));

	$wp_customize->add_setting('footer_widget_areas',array(
		'default'           => 4,
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	));
	$wp_customize->add_control('footer_widget_areas',array(
		'type'        => 'radio',
		'label'       => __('Footer widget area', 'swimming-pool-cleaning'),
		'section'     => 'swimming_pool_cleaning_footer_section',
		'description' => __('Select the number of widget areas you want in the footer. After that, go to Appearance > Widgets and add your widgets.', 'swimming-pool-cleaning'),
		'choices' => array(
		   '1'     => __('One', 'swimming-pool-cleaning'),
		   '2'     => __('Two', 'swimming-pool-cleaning'),
		   '3'     => __('Three', 'swimming-pool-cleaning'),
		   '4'     => __('Four', 'swimming-pool-cleaning')
		),
	));

	$wp_customize->add_setting('swimming_pool_cleaning_hide_show_scroll',array(
		'default' => true,
		'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
	));
	$wp_customize->add_control('swimming_pool_cleaning_hide_show_scroll',array(
     	'type' => 'checkbox',
      	'label' => __('Enable / Disable Back To Top','swimming-pool-cleaning'),
      	'section' => 'swimming_pool_cleaning_footer_section',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_back_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_back_to_top_icon',array(
		'label'	=> __('Back to Top Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_footer_section',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_scroll_icon_font_size',array(
		'default'=> 22,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_scroll_icon_font_size',array(
		'label'	=> __('Back To Top Icon Font Size','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_footer_options',array(
        'default' => 'Right align',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_footer_options',array(
        'type' => 'radio',
        'label' => __('Back To Top Alignment','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_footer_section',
        'choices' => array(
            'Left align' => __('Left Align','swimming-pool-cleaning'),
            'Right align' => __('Right Align','swimming-pool-cleaning'),
            'Center align' => __('Center Align','swimming-pool-cleaning'),
        ),
	) );

	$wp_customize->add_setting( 'swimming_pool_cleaning_top_bottom_scroll_padding',array(
		'default' => 7,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_top_bottom_scroll_padding',	array(
		'label' => esc_html__( 'Top Bottom Scroll Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_left_right_scroll_padding',array(
		'default' => 17,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_left_right_scroll_padding',	array(
		'label' => esc_html__( 'Left Right Scroll Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_back_to_top_border_radius',array(
		'default' => 50,
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_back_to_top_border_radius', array(
		'label' => esc_html__( 'Back to Top Border Radius (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_footer_copy',array(
		'label'	=> __('Copyright Text','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_footer_section',
		'description'	=> __('Add some text for footer like copyright etc.','swimming-pool-cleaning'),
		'type'		=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_footer_text_align',array(
        'default' => 'center',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_footer_text_align',array(
        'type' => 'radio',
        'label' => __('Copyright Text Alignment ','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_footer_section',
        'choices' => array(
            'left' => __('Left Align','swimming-pool-cleaning'),
            'right' => __('Right Align','swimming-pool-cleaning'),
            'center' => __('Center Align','swimming-pool-cleaning'),
        ),
	) );

	$wp_customize->add_setting('swimming_pool_cleaning_copyright_text_font_size',array(
		'default'=> 15,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_copyright_text_font_size',array(
		'label' => esc_html__( 'Copyright Font Size (px)','swimming-pool-cleaning' ),
		'section'=> 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_footer_text_padding',array(
		'default' => 20,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_footer_text_padding',	array(
		'label' => esc_html__( 'Copyright Text Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_footer_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_copyright_text_background', array(
		'default'           => '#FFBB3B',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_copyright_text_background', array(
		'label'    => __('Copyright background Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_footer_section',
	)));

	//Responsive Media Settings
	$wp_customize->add_section('swimming_pool_cleaning_responsive_media',array(
		'title'	=> __('Responsive Media','swimming-pool-cleaning'),
		'panel' => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_responsive_menu_open_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_responsive_menu_open_icon',array(
		'label'	=> __('Responsive Open Menu Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_responsive_media',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_open_menu_label',array(
       'default' => __('Menu','swimming-pool-cleaning'),
       'sanitize_callback'	=> 'sanitize_text_field'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_open_menu_label',array(
       'type' => 'text',
       'label' => __('Open Menu Label','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
   ));

	$wp_customize->add_setting('swimming_pool_cleaning_responsive_menu_close_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Icon_Changer(
        $wp_customize,'swimming_pool_cleaning_responsive_menu_close_icon',array(
		'label'	=> __('Responsive Close Menu Icon','swimming-pool-cleaning'),
		'transport' => 'refresh',
		'section'	=> 'swimming_pool_cleaning_responsive_media',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_close_menu_label',array(
       'default' => __('Close Menu','swimming-pool-cleaning'),
       'sanitize_callback' => 'sanitize_text_field'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_close_menu_label',array(
       'type' => 'text',
       'label' => __('Close Menu Label','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
   ));

	// site toggle button color
	$wp_customize->add_setting('swimming_pool_cleaning_toggle_button_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'swimming_pool_cleaning_toggle_button_color', array(
		'label'    => __('Toggle Button Color', 'swimming-pool-cleaning'),
		'section'  => 'swimming_pool_cleaning_responsive_media',
		'settings' => 'swimming_pool_cleaning_toggle_button_color',
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_display_post_date',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_post_date',array(
       'type' => 'checkbox',
       'label' => __('Display Post Date','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_display_post_author',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_post_author',array(
       'type' => 'checkbox',
       'label' => __('Display Post Author','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_display_post_comment',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_post_comment',array(
       'type' => 'checkbox',
       'label' => __('Display Post Comment','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_display_slider',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_slider',array(
       'type' => 'checkbox',
       'label' => __('Display Slider','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

	$wp_customize->add_setting('swimming_pool_cleaning_display_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Display Sidebar','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_display_scrolltop',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_scrolltop',array(
       'type' => 'checkbox',
       'label' => __('Display Scroll To Top','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_display_preloader',array(
       'default' => false,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_display_preloader',array(
       'type' => 'checkbox',
       'label' => __('Display Preloader','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_responsive_media'
    ));

    //404 Page Setting
	$wp_customize->add_section('swimming_pool_cleaning_page_not_found',array(
		'title'	=> __('404 Page Not Found / No Result','swimming-pool-cleaning'),
		'panel' => 'swimming_pool_cleaning_panel_id',
	));

	$wp_customize->add_setting('swimming_pool_cleaning_page_not_found_heading',array(
		'default'=> __('404 Not Found','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_page_not_found_heading',array(
		'label'	=> __('404 Heading','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_page_not_found',
		'type'=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_page_not_found_text',array(
		'default'=> __('Looks like you have taken a wrong turn. Dont worry it happens to the best of us.','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_page_not_found_text',array(
		'label'	=> __('404 Content','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_page_not_found',
		'type'=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_page_not_found_button',array(
		'default'=>  __('Back to Home Page','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_page_not_found_button',array(
		'label'	=> __('404 Button','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_page_not_found',
		'type'=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_no_search_result_heading',array(
		'default'=> __('Nothing Found','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_no_search_result_heading',array(
		'label'	=> __('No Search Results Heading','swimming-pool-cleaning'),
		'description'=>__('The search page heading display when no results are found.','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_page_not_found',
		'type'=> 'text'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_no_search_result_text',array(
		'default'=> __('Sorry, but nothing matched your search terms. Please try again with some different keywords.','swimming-pool-cleaning'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_no_search_result_text',array(
		'label'	=> __('No Search Results Text','swimming-pool-cleaning'),
		'description'=>__('The search page text display when no results are found.','swimming-pool-cleaning'),
		'section'=> 'swimming_pool_cleaning_page_not_found',
		'type'=> 'text'
	));

	//Woocommerce Section
	$wp_customize->add_section( 'swimming_pool_cleaning_woocommerce_section' , array(
    	'title'      => __( 'Woocommerce Settings', 'swimming-pool-cleaning' ),
    	'description'=>__('The below settings are apply on woocommerce pages.','swimming-pool-cleaning'),
		'priority'   => null,
		'panel' => 'swimming_pool_cleaning_panel_id'
	) );

	/**
	 * Product Columns
	 */
	$wp_customize->add_setting( 'swimming_pool_cleaning_per_columns' , array(
		'default'           => 3,
		'transport'         => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices',
	) );
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'swimming_pool_cleaning_per_columns', array(
		'label'    => __( 'Product per columns', 'swimming-pool-cleaning' ),
		'section'  => 'swimming_pool_cleaning_woocommerce_section',
		'type'     => 'select',
		'choices'  => array(
			'2' => '2',
			'3' => '3',
			'4' => '4',
			'5' => '5',
		),
	) ) );

	$wp_customize->add_setting('swimming_pool_cleaning_product_per_page',array(
		'default'	=> 9,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('swimming_pool_cleaning_product_per_page',array(
		'label'	=> __('Product per page','swimming-pool-cleaning'),
		'section'	=> 'swimming_pool_cleaning_woocommerce_section',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('swimming_pool_cleaning_shop_sidebar_enable',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_shop_sidebar_enable',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable shop page sidebar','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_woocommerce_section',
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_product_page_sidebar_enable',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_product_page_sidebar_enable',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable product page sidebar','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_woocommerce_section',
    ));

    $wp_customize->add_setting('swimming_pool_cleaning_related_product_enable',array(
       'default' => true,
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_related_product_enable',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related product','swimming-pool-cleaning'),
       'section' => 'swimming_pool_cleaning_woocommerce_section',
    ));

    $wp_customize->add_setting( 'swimming_pool_cleaning_woo_product_sale_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woo_product_sale_border_radius', array(
        'label'  => __('Woocommerce Product Sale Border Radius','swimming-pool-cleaning'),
        'section'  => 'swimming_pool_cleaning_woocommerce_section',
        'type'        => 'number',
        'input_attrs' => array(
        	'step'=> 1,
            'min' => 0,
            'max' => 50,
        )
    )));

    $wp_customize->add_setting('swimming_pool_cleaning_wooproduct_sale_font_size',array(
		'default'=> 14,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_wooproduct_sale_font_size',array(
		'label'	=> __('Woocommerce Product Sale Font Size','swimming-pool-cleaning'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'swimming_pool_cleaning_woocommerce_section',
	)));

    $wp_customize->add_setting('swimming_pool_cleaning_woo_product_sale_top_bottom_padding',array(
		'default'=> 0,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woo_product_sale_top_bottom_padding',array(
		'label'	=> __('Woocommerce Product Sale Top Bottom Padding ','swimming-pool-cleaning'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'swimming_pool_cleaning_woocommerce_section',
		'type'=> 'number'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_woo_product_sale_left_right_padding',array(
		'default'=> 0,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woo_product_sale_left_right_padding',array(
		'label'	=> __('Woocommerce Product Sale Left Right Padding','swimming-pool-cleaning'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'swimming_pool_cleaning_woocommerce_section',
		'type'=> 'number'
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_woo_product_sale_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'swimming_pool_cleaning_sanitize_choices'
	));
	$wp_customize->add_control('swimming_pool_cleaning_woo_product_sale_position',array(
        'type' => 'select',
        'label' => __('Woocommerce Product Sale Position','swimming-pool-cleaning'),
        'section' => 'swimming_pool_cleaning_woocommerce_section',
        'choices' => array(
            'Right' => __('Right','swimming-pool-cleaning'),
            'Left' => __('Left','swimming-pool-cleaning'),
        ),
	));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_button_padding_top',array(
		'default' => 12,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_button_padding_top',	array(
		'label' => esc_html__( 'Button Top Bottom Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_button_padding_right',array(
		'default' => 15,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_button_padding_right',	array(
		'label' => esc_html__( 'Button Right Left Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_button_border_radius',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_button_border_radius',array(
		'label' => esc_html__( 'Button Border Radius (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

   $wp_customize->add_setting('swimming_pool_cleaning_woocommerce_product_border_enable',array(
      'default' => true,
      'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_checkbox'
   ));
   $wp_customize->add_control('swimming_pool_cleaning_woocommerce_product_border_enable',array(
      'type' => 'checkbox',
      'label' => __('Enable / Disable product border','swimming-pool-cleaning'),
      'section' => 'swimming_pool_cleaning_woocommerce_section',
   ));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_product_padding_top',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_product_padding_top',	array(
		'label' => esc_html__( 'Product Top Bottom Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_product_padding_right',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_product_padding_right',	array(
		'label' => esc_html__( 'Product Right Left Padding (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_product_border_radius',array(
		'default' => 3,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_product_border_radius',array(
		'label' => esc_html__( 'Product Border Radius (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting( 'swimming_pool_cleaning_woocommerce_product_box_shadow',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'swimming_pool_cleaning_sanitize_integer'
	));
	$wp_customize->add_control( new Swimming_Pool_Cleaning_Custom_Control( $wp_customize, 'swimming_pool_cleaning_woocommerce_product_box_shadow',array(
		'label' => esc_html__( 'Product Box Shadow (px)','swimming-pool-cleaning' ),
		'section' => 'swimming_pool_cleaning_woocommerce_section',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	)));

	$wp_customize->add_setting('swimming_pool_cleaning_wooproducts_nav',array(
       'default' => 'Yes',
       'sanitize_callback'	=> 'swimming_pool_cleaning_sanitize_choices'
    ));
    $wp_customize->add_control('swimming_pool_cleaning_wooproducts_nav',array(
       'type' => 'select',
       'label' => __('Shop Page Products Navigation','swimming-pool-cleaning'),
       'choices' => array(
            'Yes' => __('Yes','swimming-pool-cleaning'),
            'No' => __('No','swimming-pool-cleaning'),
        ),
       'section' => 'swimming_pool_cleaning_woocommerce_section',
    ));

}
add_action( 'customize_register', 'swimming_pool_cleaning_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Swimming_Pool_Cleaning_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Swimming_Pool_Cleaning_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Swimming_Pool_Cleaning_Customize_Section_Pro(
				$manager,
				'swimming_pool_cleaning_example_1',
				array(
					'title'   =>  esc_html__( 'Swimming Pool Cleaning Pro', 'swimming-pool-cleaning' ),
					'pro_text' => esc_html__( 'Go Pro', 'swimming-pool-cleaning' ),
					'pro_url'  => esc_url( 'https://www.buywptemplates.com/themes/swimming-pool-wordpress-theme/' ),
					'priority'   => 9
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'swimming-pool-cleaning-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'swimming-pool-cleaning-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/css/customize-controls.css' );
	}

	//Footer widget areas
	function swimming_pool_cleaning_sanitize_choices( $input ) {
	    $valid = array(
	        '1'     => __('One', 'swimming-pool-cleaning'),
	        '2'     => __('Two', 'swimming-pool-cleaning'),
	        '3'     => __('Three', 'swimming-pool-cleaning'),
	        '4'     => __('Four', 'swimming-pool-cleaning')
	    );
	    if ( array_key_exists( $input, $valid ) ) {
	        return $input;
	    } else {
	        return '';
	    }
	}
}

// Doing this customizer thang!
Swimming_Pool_Cleaning_Customize::get_instance();
